bvar.sv.tvp(Y, p = 1, tau = 40, nf = 10, pdrift = TRUE, nrep = 50000,
nburn = 5000, thinfac = 10, itprint = 10000, k_B = 4, k_A = 4, k_sig = 1,
k_Q = 0.01, k_S = 0.1, k_W = 0.01, pQ = NULL, pW = NULL, pS = NULL)Y must have at least two columns.Y[1:tau, ] are used for estimating prior parameters via LS; formal Bayesian analysis is then performed for data in Y[(tau+1):nrfc.mdraws, fc.vdraws, fc.ydraws, see below) contain only every tenth draw of the original sequence. Set thinfac titprint-th iteration. Defaults to 10000. Set to very large value to omit printing altogether.Y), and $M$ denotes the number of system variables (= number of columns of Y). The submatrix $[, , t]$ represents the coefficient matrix at time $t$. The intercept vector is stacked in the first column; the p coefficient matrices of dimension $[M,M]$ are placed next to it.nrep/thinfac, apart from possible rounding issues.fc.mdraws, except that the first array dimension contains the lower-diagonal elements of the forecast covariance matrix.fc.mdraws.predictive.density and predictive.draws provide simple access to the forecast distribution produced by bvar.sv.tvp. For detailed examples and explanations, see the accompanying pdf file hosted at # Load US macro data
data(usmacro)
# Estimate trivariate BVAR using default settings
set.seed(5813)
bv <- bvar.sv.tvp(usmacro)Run the code above in your browser using DataLab